@@ -17,8 +17,8 @@
   
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 
@@ -74,7 +74,7 @@ html_string_tokenizer_tokenize (HTMLStringTokenizer *t,
 	gint str_length;
 
 	if (*str == '\0') {
-		t->pos = 0;
+		t->pos = NULL;
 		return;
 	}
 	
